<?php

namespace Drupal\hospital_price_transparency\Controller;

use Drupal\Core\Cache\CacheableResponse;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\BinaryFileResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\ResponseHeaderBag;

/**
 * Returns responses for Hospital Price Transparency routes.
 */
class HospitalPriceTransparencyController extends ControllerBase {

  /**
   * Serves contents of the hospital_price_transparency file.
   */
  public function file($hpt) {
    /** @var Drupal\hospital_price_transparency\HospitalPriceTransparencyInterface $hpt */
    $hpt = $this->entityTypeManager()->getStorage('hpt')->load($hpt);
    if ($hpt) {
      $access = $hpt->access('view', NULL, TRUE);
      if ($access->isAllowed()) {
        if ($file = $hpt->getFile()) {
          $file_access = $file->access('view', NULL, TRUE);
          if ($file_access->isAllowed()) {
            $response = new BinaryFileResponse($file->getFileUri());
            // Use fpassthru rather than file_get_contents to help with
            // memory allocation problems with huge files.
            $disposition = $response->headers->makeDisposition(
              ResponseHeaderBag::DISPOSITION_ATTACHMENT,
              $hpt->getFileAlias()
            );
            $response->headers->set('Content-Disposition', $disposition);
            $response->headers->set('Content-Type', $file->getMimeType());
            $response->headers->set('Content-Length', $file->getSize());
            return $response;
          }
          else {
            $response = new CacheableResponse($this->t('You are not allowed to view this Hospital Price Transparency document.'), Response::HTTP_FORBIDDEN);
            $response->addCacheableDependency($file_access);
            $response->addCacheableDependency($access);
            $response->addCacheableDependency($hpt);
            return $response;
          }
        }
      }
      else {
        $response = new CacheableResponse($this->t('You are not allowed to view this Hospital Price Transparency document.'), Response::HTTP_FORBIDDEN);
        $response->addCacheableDependency($access);
        $response->addCacheableDependency($hpt);
        return $response;
      }
    }
    $response = new CacheableResponse($this->t('The Hospital Price Transparency document was not found.'), Response::HTTP_NOT_FOUND);
    $response->addCacheableDependency($hpt);
    return $response;
  }

}
